pub struct SetControllers {
pub _set_controllers_arg: SetControllersArg,
pub _eth_signature: Option<Secp256k1RawSignature>,
}Expand description
Instruction.
Fields
_set_controllers_arg: SetControllersArg_eth_signature: Option<Secp256k1RawSignature>Trait Implementations
Sourceimpl BorshDeserialize for SetControllers
impl BorshDeserialize for SetControllers
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetControllers
impl BorshSerialize for SetControllers
Sourceimpl Discriminator for SetControllers
impl Discriminator for SetControllers
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for SetControllers
impl InstructionData for SetControllers